@@ -10,6 +10,7 @@ __all__ = [
     "cmrc",
     "record",
     "hotpotqa",
+    "smcalflow",
 ]
 
 
@@ -24,3 +25,4 @@ from sota_extractor.scrapers.chexpert import chexpert
 from sota_extractor.scrapers.cmrc import cmrc
 from sota_extractor.scrapers.record import record
 from sota_extractor.scrapers.hotpotqa import hotpotqa
+from sota_extractor.scrapers.smcalflow import smcalflow
